<?php
/**
 *
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\OrderAdditionalData\Model\Plugin;

/*
 * Add Order Increment ID to Shipment
 */

use Magento\Framework\App\Helper\Context;
use Magento\Sales\Api\Data\ShipmentExtensionFactory;
use Magento\Sales\Api\Data\ShipmentInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Sales\Api\ShipmentRepositoryInterface;

/**
 * Class ShipmentGet
 * @package FiloBlu\OrderAdditionalData\Model\Plugin
 */
class ShipmentGet
{

    /**
     * @var OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var ShipmentExtensionFactory
     */
    protected $shipmentExtensionFactory;

    /**
     * ShipmentGet constructor.
     * @param Context $context
     * @param OrderRepositoryInterface $orderRepository
     * @param ShipmentExtensionFactory $shipmentExtensionFactory
     */
    public function __construct(
        Context $context,
        OrderRepositoryInterface $orderRepository,
        ShipmentExtensionFactory $shipmentExtensionFactory
    ) {
        $this->orderRepository = $orderRepository;
        $this->shipmentExtensionFactory = $shipmentExtensionFactory;
    }

    /**
     * Add Order increment ID
     *
     * @param ShipmentRepositoryInterface $subject
     * @param ShipmentInterface $shipment
     * @return ShipmentInterface
     */
    public function afterGet(
        ShipmentRepositoryInterface $subject,
        ShipmentInterface $shipment
    ) {
        $extensionAttributes = $shipment->getExtensionAttributes();
        $shipmentExtension = $extensionAttributes ?: $this->shipmentExtensionFactory->create();
        $order_increment_id = $shipment->getData('order_increment_id');
        if ($order_increment_id === null) {
            $order = $this->orderRepository->get($shipment->getOrderId());
            $order_increment_id = $order->getIncrementId();
            $shipment->setData('order_increment_id', $order_increment_id);
            $shipment->save();
        }
        $shipmentExtension->setData('order_increment_id', $order_increment_id);
        $shipment->setExtensionAttributes($shipmentExtension);
        return $shipment;
    }
}
